progress

package
v0.0.20 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 18, 2025 License: MIT Imports: 3 Imported by: 1

Documentation

Overview

templ: version: v0.3.943

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CircularProgress

func CircularProgress(fraction float64, status Status, size int, showIcon bool) templ.Component

CircularProgress renders a basic circular progress indicator

func CircularProgressWithLabel

func CircularProgressWithLabel(fraction float64, status Status, size int, showIcon bool, label string) templ.Component

CircularProgressWithLabel adds a text label below the progress indicator

func LargeProgress

func LargeProgress(fraction float64, status Status) templ.Component

Large variants

func LargeProgressWithLabel

func LargeProgressWithLabel(fraction float64, status Status, label string) templ.Component

func Progress

func Progress(fraction float64, status Status) templ.Component

Medium variants

func ProgressWithLabel

func ProgressWithLabel(fraction float64, status Status, label string) templ.Component

WithLabel variants

func SmallComplete

func SmallComplete() templ.Component

func SmallFailed

func SmallFailed() templ.Component

func SmallPending

func SmallPending() templ.Component

Small variants for different statuses

func SmallRunning

func SmallRunning(fraction float64) templ.Component

Types

type Status

type Status string

Status represents the current state of a progress indicator

const (
	StatusPending  Status = "pending"
	StatusRunning  Status = "running"
	StatusComplete Status = "complete"
	StatusFailed   Status = "failed"
)

Jump to